==> react-native-immutable-list-view-0.4.3.tgz: package/lib/ImmutableVirtualizedList.js <==
Object.defineProperty(exports,"__esModule",{value:true});var _extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i];for(var key in source){if(Object.prototype.hasOwnProperty.call(source,key)){target[key]=source[key];}}}return target;};var _createClass=function(){function defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||false;descriptor.configurable=true;if("value"in descriptor)descriptor.writable=true;Object.defineProperty(target,descriptor.key,descriptor);}}return function(Constructor,protoProps,staticProps){if(protoProps)defineProperties(Constructor.prototype,protoProps);if(staticProps)defineProperties(Constructor,staticProps);return Constructor;};}();var _immutable=require('immutable');var _immutable2=_interopRequireDefault(_immutable);
var _react=require('react');var _react2=_interopRequireDefault(_react);





var _VirtualizedList=require('react-native/Libraries/Lists/VirtualizedList');var _VirtualizedList2=_interopRequireDefault(_VirtualizedList);

var _utils=require('./utils');var _utils2=_interopRequireDefault(_utils);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj};}function _classCallCheck(instance,Constructor){if(!(instance instanceof Constructor)){throw new TypeError("Cannot call a class as a function");}}function _possibleConstructorReturn(self,call){if(!self){throw new ReferenceError("this hasn't been initialised - super() hasn't been called");}return call&&(typeof call==="object"||typeof call==="function")?call:self;}function _inherits(subClass,superClass){if(typeof superClass!=="function"&&superClass!==null){throw new TypeError("Super expression must either be null or a function, not "+typeof superClass);}subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,enumerable:false,writable:true,configurable:true}});if(superClass)Object.setPrototypeOf?Object.setPrototypeOf(subClass,superClass):subClass.__proto__=superClass;}var






ImmutableVirtualizedList=function(_PureComponent){_inherits(ImmutableVirtualizedList,_PureComponent);function ImmutableVirtualizedList(){_classCallCheck(this,ImmutableVirtualizedList);return _possibleConstructorReturn(this,(ImmutableVirtualizedList.__proto__||Object.getPrototypeOf(ImmutableVirtualizedList)).apply(this,arguments));}_createClass(ImmutableVirtualizedList,[{key:'scrollToEnd',value:function scrollToEnd()





















{var _virtualizedListRef;
return this.virtualizedListRef&&(_virtualizedListRef=this.virtualizedListRef).scrollToEnd.apply(_virtualizedListRef,arguments);
}},{key:'scrollToIndex',value:function scrollToIndex()

{var _virtualizedListRef2;
return this.virtualizedListRef&&(_virtualizedListRef2=this.virtualizedListRef).scrollToIndex.apply(_virtualizedListRef2,arguments);
}},{key:'scrollToItem',value:function scrollToItem()

{var _virtualizedListRef3;
return this.virtualizedListRef&&(_virtualizedListRef3=this.virtualizedListRef).scrollToItem.apply(_virtualizedListRef3,arguments);
}},{key:'scrollToOffset',value:function scrollToOffset()

{var _virtualizedListRef4;
return this.virtualizedListRef&&(_virtualizedListRef4=this.virtualizedListRef).scrollToOffset.apply(_virtualizedListRef4,arguments);
}},{key:'recordInteraction',value:function recordInteraction()

{var _virtualizedListRef5;
return this.virtualizedListRef&&(_virtualizedListRef5=this.virtualizedListRef).recordInteraction.apply(_virtualizedListRef5,arguments);
}},{key:'render',value:function render()

{var _this2=this;var
immutableData=this.props.immutableData;

return(
_react2.default.createElement(_VirtualizedList2.default,_extends({
ref:function ref(virtualizedList){_this2.virtualizedListRef=virtualizedList;},
data:immutableData,
getItem:function getItem(items,index){return _utils2.default.getValueFromKey(index,items);},
getItemCount:function getItemCount(items){return items.size||items.length||0;},
keyExtractor:function keyExtractor(item,index){return String(index);}},
this.props)));


}}]);return ImmutableVirtualizedList;}(_react.PureComponent);ImmutableVirtualizedList.propTypes=_extends({},_VirtualizedList2.default.propTypes,{immutableData:function immutableData(props,propName,componentName){if(_immutable2.default.Map.isMap(props[propName])){return new Error('Invalid prop '+propName+' supplied to '+componentName+': Support for Immutable.Map is coming soon. For now, try an Immutable List, Set, or Range.');}else if(!_utils2.default.isImmutableIterable(props[propName])){return new Error('Invalid prop '+propName+' supplied to '+componentName+': Must be instance of Immutable.Iterable.');}}});exports.default=



ImmutableVirtualizedList;

==> react-native-immutable-list-view-0.5.0.tgz: package/lib/ImmutableVirtualizedList.js <==
Object.defineProperty(exports,"__esModule",{value:true});var _extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i];for(var key in source){if(Object.prototype.hasOwnProperty.call(source,key)){target[key]=source[key];}}}return target;};var _createClass=function(){function defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||false;descriptor.configurable=true;if("value"in descriptor)descriptor.writable=true;Object.defineProperty(target,descriptor.key,descriptor);}}return function(Constructor,protoProps,staticProps){if(protoProps)defineProperties(Constructor.prototype,protoProps);if(staticProps)defineProperties(Constructor,staticProps);return Constructor;};}();var _immutable=require('immutable');var _immutable2=_interopRequireDefault(_immutable);
var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');

var _utils=require('./utils');var _utils2=_interopRequireDefault(_utils);function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj};}function _classCallCheck(instance,Constructor){if(!(instance instanceof Constructor)){throw new TypeError("Cannot call a class as a function");}}function _possibleConstructorReturn(self,call){if(!self){throw new ReferenceError("this hasn't been initialised - super() hasn't been called");}return call&&(typeof call==="object"||typeof call==="function")?call:self;}function _inherits(subClass,superClass){if(typeof superClass!=="function"&&superClass!==null){throw new TypeError("Super expression must either be null or a function, not "+typeof superClass);}subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,enumerable:false,writable:true,configurable:true}});if(superClass)Object.setPrototypeOf?Object.setPrototypeOf(subClass,superClass):subClass.__proto__=superClass;}var






ImmutableVirtualizedList=function(_PureComponent){_inherits(ImmutableVirtualizedList,_PureComponent);function ImmutableVirtualizedList(){_classCallCheck(this,ImmutableVirtualizedList);return _possibleConstructorReturn(this,(ImmutableVirtualizedList.__proto__||Object.getPrototypeOf(ImmutableVirtualizedList)).apply(this,arguments));}_createClass(ImmutableVirtualizedList,[{key:'getVirtualizedList',value:function getVirtualizedList()





















{
return this.virtualizedListRef;
}},{key:'scrollToEnd',value:function scrollToEnd()

{var _virtualizedListRef;
return this.virtualizedListRef&&(_virtualizedListRef=this.virtualizedListRef).scrollToEnd.apply(_virtualizedListRef,arguments);
}},{key:'scrollToIndex',value:function scrollToIndex()

{var _virtualizedListRef2;
return this.virtualizedListRef&&(_virtualizedListRef2=this.virtualizedListRef).scrollToIndex.apply(_virtualizedListRef2,arguments);
}},{key:'scrollToItem',value:function scrollToItem()

{var _virtualizedListRef3;
return this.virtualizedListRef&&(_virtualizedListRef3=this.virtualizedListRef).scrollToItem.apply(_virtualizedListRef3,arguments);
}},{key:'scrollToOffset',value:function scrollToOffset()

{var _virtualizedListRef4;
return this.virtualizedListRef&&(_virtualizedListRef4=this.virtualizedListRef).scrollToOffset.apply(_virtualizedListRef4,arguments);
}},{key:'recordInteraction',value:function recordInteraction()

{var _virtualizedListRef5;
return this.virtualizedListRef&&(_virtualizedListRef5=this.virtualizedListRef).recordInteraction.apply(_virtualizedListRef5,arguments);
}},{key:'render',value:function render()

{var _this2=this;var
immutableData=this.props.immutableData;

return(
_react2.default.createElement(_reactNative.VirtualizedList,_extends({
ref:function ref(virtualizedList){_this2.virtualizedListRef=virtualizedList;},
data:immutableData,
getItem:function getItem(items,index){return _utils2.default.getValueFromKey(index,items);},
getItemCount:function getItemCount(items){return items.size||items.length||0;},
keyExtractor:function keyExtractor(item,index){return String(index);}},
this.props)));


}}]);return ImmutableVirtualizedList;}(_react.PureComponent);ImmutableVirtualizedList.propTypes=_extends({},_reactNative.VirtualizedList.propTypes,{immutableData:function immutableData(props,propName,componentName){if(_immutable2.default.Map.isMap(props[propName])){return new Error('Invalid prop '+propName+' supplied to '+componentName+': Support for Immutable.Map is coming soon. For now, try an Immutable List, Set, or Range.');}else if(!_utils2.default.isImmutableIterable(props[propName])){return new Error('Invalid prop '+propName+' supplied to '+componentName+': Must be instance of Immutable.Iterable.');}}});exports.default=



ImmutableVirtualizedList;
